<?php
/**
* PHP igLoader wrapper for igLoader.js.
* 
*	PHP version 5
*
* 	@package        Ignite UI PHP Wrappers
* 	@version        1.0.2012.2056
*
*/

namespace ig\loader;

/**
* Server-side wrapper class for the Loader Ignite UI control.
*/
class igLoader
{
    /**
     * Indicates whether the loader should automatically detect browser's locale. Defaults to false.
     * @var bool 
     */
    public $autoDetectLocale;

    /** 
     * CSS path relative to the page that instantiates the loader. <b> Required </b>
     * @var string 
     */
    public $cssPath;

    /** 
     * Two letter code for current locale. Defaults to 'en'.
     * @var string  
     */
    public $locale;

    /** 
     * Folder name that contains localization resources.Defaults to $path$/modules/i18n
     * @var string  
     */
    public $localePath;

    /** 
    * A function to call when all resources are loaded but before the "ready" notification is sent.
    * Note: This might not be working just yet.
    * @var JSfunction
    */
    private $preinit;

    /** 
     * A function to call when all resources are loaded and ready to use.
     * Note: This might not be working just yet.
     * @var JSfunction
     */
    private $ready;

    /** 
     * Regional code. Can be two or five characters long ('en', 'en-GB'). Defaults to 'en'.
     * @var string   
     */
    public $regional;

    /** 
     * Comma separated list of resources to load. Ex: 'igTree,igVideoPlayer,igGrid.Paging'.
     * Modular widgets, such as igGrid, allow linking features with a '.' (dot). To load all modules of a widget use '*'. Ex: 'igGrid.*'.
     * @var string 
     */
    public $resources;

    /** 
     * Script path relative to the page that instantiates the loader. <b> Required </b>
     * @var string 
     */
    public $scriptPath;

    /** 
     * Name of the theme. Must correspond to the CSS theme folder under cssPath.
     * @var string
     */
    public $theme;

    /** 
    * Constructs an Ignite UI Loaderer object with he most basic required settings from parameters.
    * @param string $cssPath CSS path relative to the page that instantiates the loader. <b> Required </b>
    * @param string $scriptPath Script path relative to the page that instantiates the loader. <b> Required </b>
    * @param string $resources Comma separated list of resources to load. Recommended.
    */
    function __construct($cssPath, $scriptPath , $resources = null)
    {
            $this->cssPath = $cssPath;
            $this->scriptPath = $scriptPath;
            $this->resources = $resources;
    }

    public function __toString() 
    {
            $options = new \stdClass();;      
            foreach (get_object_vars($this) as $key => $value) {
                    if (!(!isset($value) || $value === "")) {
                            $options->$key = $value;
                    }
            }
            $result = $this->_getHtml();
            $result .= '$.ig.loader(';
            $result .= json_encode($options) . ');</script>';
            return $result;
    }

    /** 
    * Returns the actual infragistics.loader.js script tag and the opening tag for the loader code.
    * @return string
    */
    private function _getHtml()
    {
        if (substr($this->scriptPath,-1,1) == "/") {
            return '<script src="' . $this->scriptPath . 'infragistics.loader.js" type="text/javascript"></script><script type="text/javascript">';
        }
        return '<script src="' . $this->scriptPath . '/infragistics.loader.js" type="text/javascript"></script><script type="text/javascript">';
    }
}


?>
