<?php

/**
 * PHP igUpload wrapper for the Ignite UI File Upload
 * 
 * 	PHP version 5.4
 *
 * 	@package        Ignite UI PHP Wrappers
 * 	@version        1.0.2012.2056
 *
 */

namespace ig\upload;

/**
 * Server-side wrapper class for the igUpload Ignite UI control.
 */
class igUpload {

    /**
     * The ID to be user for the client-side jQuery widget(container id). Set in constructor. Required.
     * @var string
     */
    public $id = 'igUploadID';

    /**
     * Width of the main container of the file upload control. Main container contains all buttons, progressbar, etc.
     * @var int 
     */
    public $width;

    /**
     * Height of the main container of the file upload control. Main container contains all buttons, progressbar, etc. 
     * @var int 
     */
    public $height;

    /**
     * An array of allowed extension strings (e.g. "gif", "jpg", "bmp").
     * @var array  
     */
    public $allowedExtensions;

    /**
     * Whether the file start upload automatically when it is selected. Default is false.
     * @var bool  
     */
    public $autostartupload;

    /**
     * Unique Id of the control - should not be changed by developer. Set from server-side.
     *
     * @var string $controlId 
     * @access private
     */
    public $controlId;

    /**
     * Control-specific CSS options. Use override specific control classes with custom ones.
     * @var object $css 
     */
    public $css;

    /**
     * URL for uploading. <b> Required. </b>
     * @var string   
     */
    public $uploadUrl;

    /**
     * URL of HTTPHandler to get information about file upload; current size and also to get commands. <b> Required for non-HTML5 browsers. </b>
     * @var string 
     */
    public $progressUrl;

    /**
     * Whether to show File Extension icon 
     * @var bool 
     */
    public $showFileExtensionIcon;

    /**
     * An array of igFileExtensionIcon objects. Default is empty.
     * @var ig\upload\igFileExtensionIcon[]
     * @see igFileExtensionIcon
     */
    public $fileExtensionIcons;

    /**
     * Multiple or single file upload. In single upload it is possible to upload only one file at the same time.
     * @var ig\upload\UploadMode
     */
    public $mode = UploadMode::Single;

    /**
     * The maximum number of allowed files to upload. Default is -1(unlimited).
     * @var int 
     */
    public $maxUploadedFiles = -1;

    /**
     * Count of files that could be uploaded at the same time. Default is 1. 
     * @var int 
     */
    public $maxSimultaneousFilesUploads = 1;

    /**
     * $fileSizeMetric Display metric for file size.
     * @var FileSizeMetric
     */
    public $fileSizeMetric = FileSizeMetric::MBytes;

    /**
     * The number of digits after the decimal point. 
     * @var int
     */
    public $fileSizeDecimalDisplay = 2;
    
    /**
     * The maximum file size to accept (LESS THAN php.ini settings) in bytes.
     * @var int 
     * @access private
     */
    private $_maxFileSize;

    /*     * #@+
     * Label or error message string to override.
     * @var string
     * @access public
     */
    public $labelUploadButton = "";
    public $publiclabelAddButton = "";
    public $labelClearAllButton = "";
    public $labelSummaryTemplate = "";
    public $labelSummaryProgressBarTemplate = "";
    public $labelShowDetails = "";
    public $labelHideDetails = "";
    public $labelSummaryProgressButtonCancel = "";
    public $labelSummaryProgressButtonContinue = "";
    public $labelSummaryProgressButtonDone = "";
    public $labelProgressBarFileNameContinue = "";
    public $errorMessageMaxFileSizeExceeded = "";
    public $errorMessageGetFileStatus = "";
    public $errorMessageCancelUpload = "";
    public $errorMessageNoSuchFile = "";
    public $errorMessageOther = "";
    public $errorMessageValidatingFileExtension = "";
    public $errorMessageAJAXRequestFileSize = "";
    public $errorMessageTryToRemoveNonExistingFile = "";
    public $errorMessageTryToStartNonExistingFile = "";
    public $errorMessageMaxUploadedFiles = "";
    public $errorMessageMaxSimultaneousFiles = "";

    /*     * #@- */

    /**
     * Constructs an Ignite UI Upload object with he most basic required settings from parameters.
     * @param string $id The ID to be user for the client-side jQuery widget(container id). Required.
     * @param string $uploadUrl URL for uploading. <b> Required. </b>
     * @param string $progressUrl URL of HTTPHandler to get information about file upload; current size and also to get commands. <b> Required for non-HTML5 browsers. </b>
     */
    function __construct($id, $uploadUrl, $progressUrl) {
        $this->id = $id;
        $this->controlId = $id;
        $this->uploadUrl = $uploadUrl;
        $this->progressUrl = $progressUrl;
    }
    
    /**
     * Set the maximum file size to accept (LESS THAN php.ini settings).
     * <b> Your mileage may vary - field not guaranteed to do much. </b>
     * @param int $maxFileSize Maximum file size in bytes
     */
    public function setMaximumFileSize($maxFileSize){
        $this->_maxFileSize = $maxFileSize;
    }

    function __toString() {
        $options = new \stdClass();
        ;
        foreach (get_object_vars($this) as $key => $value) {
            if (!(!isset($value) || $value === "")) {
                $options->$key = $value;
            }
        }
        $result = $this->_getHtml();

        if (class_exists('ig\loader\igLoader')) {
            $result .= '<script type="text/javascript">$.ig.loader(function () {$("#' . $this->id . '")';
        } else {
            $result .= '<script type="text/javascript">$(function(){$("#' . $this->id . '")';
        }
        $result .= '.igUpload(';
        $result .= json_encode($options) . ');});</script>';
        $result .= $this->_getHackyScripts();
        return $result;
    }

    /**
     * Returns the continer div and hidden div for session tracking
     * @return string
     * @access private
     */
    private function _getHtml() {
        return '<div id="' . $this->id . '"></div>';
    }

    /**
     * Returns an additional script tag with hook for the form submit to enable PHP to track progress.
     * Also in case of intila file register (size check) places some additional info instead.
     * @return string
     * @access private
     */
    private function _getHackyScripts() {
        return '
		<script type="text/javascript">$(document).on("submit", "form[id^=\'' . $this->id . '\']" , function(event) {
			'
                . 'var command = event.target.action.split("?")[1].split("&")[1].split("command=")[1];'
                . 'if (command == "fileSize") {'
                . 'var fileInput = $(event.target).children().last();'
                . 'var filename = fileInput.attr("name");'
                // can get file name from here, path is fake obv.
                //. 'var fileVal =  fileInput.val();'
                . 'fileInput.replaceWith($("<input type=\'hidden\' name=\'filename\' value=\'" + filename + "\' />"));'
                . '$(\'<input type="hidden" name="cid" value="\' + event.target.id.split("__")[0] + \'" />\').prependTo(event.target);'
                . '}else{'
                . $this->_fileSizeHiddenInput()
                . '$(\'<input type="hidden" name="' . ini_get("session.upload_progress.name") . '" value="\' + event.target.id.split("__")[0] + \'" />\').prependTo(event.target);'
                . '}
		});
                $.ajaxPrefilter(function( options, originalOptions, jqXHR ) {
                var originalSuccess = options.success;
                options.success = function (data) {
                    var command = originalOptions.url.split("?")[1].split("&")[1].split("command=")[1];
                    var key = originalOptions.url.split("?")[1].split("&")[0].split("key=")[1];
                    if (command == "status") {
                        var fileInfo = $("#' . $this->id . '").data("igUpload").getFileInfoData();
                        for(var i = 0; i < fileInfo.filesInfo.length; i++){
                            if (fileInfo.filesInfo[i] && (fileInfo.filesInfo[i].key == key) && (fileInfo.filesInfo[i].sizeBytes == 0)) {
                                fileInfo.filesInfo[i].sizeBytes = data.size; 
                                fileInfo.fileSizeTotal += data.size;
                            }
                        }
                    }
                    if (originalSuccess != null) {
                        originalSuccess(data);
                    }
                }
            });
            $(document).delegate("#' . $this->id . '", "iguploadfileselected", function (evt, ui) {
                if ($("#' . $this->id . '").data("igUpload").options.autostartupload) {
                    var key = $("#' . $this->id . '").igUpload("getFileInfoData").filesInfo[ui.fileId].key;
                    $.ajax({
                        async: false,
                        url: \'' . $this->uploadUrl . '?key=\' + key + \'&command=fileSize\',
                        type: "POST",
                        data: {\'cid\': \'' . $this->id . '_\' + ui.fileId, \'filename\': event.target.id || evt.srcElement.id }
                    });
                }
            }); 
            </script>';
    }
    
    /**
     * Returns an additional script tag with hook for the form submit to enable PHP to track progress.
     * Also in case of intila file register (size check) places some additional info instead.
     * @return string
     * @access private
     */
    private function _fileSizeHiddenInput() {
        if (isset($this->_maxFileSize)) {
         return '$(\'<input type="hidden" name="MAX_FILE_SIZE" value="' . $this->_maxFileSize . '" />\').prependTo(event.target);';
        }
        else{
            return "";
        }
    }
}

/**
 * Object wrapper for the file type icon css.
 */
class igFileExtensionIcon {

    /**
     * An array of extension strings (e.g. "gif", "jpg", "bmp").
     * @var array
     */
    public $ext = array();

    /**
     * Css classes which sets icon.
     * @var string 
     */
    public $css = "";

    /**
     * Default icons when the file extension is not found. 
     * @var bool
     */
    public $def = false;

}

/**
 * Upload mode enum
 */
class UploadMode {
    /**
     * Single
     * @var const
     */

    const Single = 'single';
    /**
     * Multiple
     * @var const
     */
    const Multiple = 'multiple';

}

/**
 * File size metric enum
 */
class FileSizeMetric {

    const Bytes = 'bytes';
    const KBytes = 'kbytes';
    const MBytes = 'mbytes';
    const GBytes = 'gbytes';
    const Auto = 'auto';

}

?>
