<?php

/**
 * Upload Module for the Ignite UI File Upload
 * 
 * 	PHP version 5.4
 * 
 * 	@package        Ignite UI PHP Wrappers
 * 	@version        1.0.2012.2056
 *
 */

namespace ig\upload;
require_once '/IG/config.php';
/**
 * Module to handle requests and file uploads made by the Ignite UI Uploader
 *
 */
class igUploadModule {
    
    /**
     * Internal array of registered event handlers
     * @var array 
     */
    protected $_callbacks = array();
    
    /**
     * Function to handle incoming file registers and uploads.
     */
    function handleRequests(){
        session_start();
        //file register or empty request?
        if (isset($_GET["command"]) && $_GET["command"] == 'fileSize') {
            //save key to id relation:
            $fileInputName = $_POST["filename"];
            $_SESSION[$_GET["key"]] = array("fileInputName" => $fileInputName, "size" => 0, "key" => ini_get("session.upload_progress.prefix") . $_POST["cid"]);
            session_write_close();
            return;
        }elseif(empty($_FILES)) {
            return;       
        }
        //file post:
        $fileInputName = isset($_SESSION[$_GET["key"]]) ? $_SESSION[$_GET["key"]]["fileInputName"] : array_keys($_FILES)[0];
        if (isset($_SESSION[$_GET["key"]]) && $_SESSION[$_GET["key"]]["size"] == 0) {
            //needed for when files are way too small to have the handler extract size from session progress.
            $_SESSION[$_GET["key"]]["size"] = $_FILES[$fileInputName]["size"];
        }
        
        $extension = pathinfo($_FILES[$fileInputName]["name"], PATHINFO_EXTENSION);
        
        //file checks
        if (in_array(strtolower($extension), Config::$allowedExts)
                && in_array($_FILES[$fileInputName]["type"], Config::$acceptedMimes)
                && ($_FILES[$fileInputName]["size"] < Config::$maxFileSizeLimit)
                && $_FILES[$fileInputName]["error"] == 0) {
            
            if (file_exists(Config::$fileUploadPath . $_FILES[$fileInputName]["name"])) {
                $_SESSION[$_GET["key"]]["serverMessage"] = "File already exsists";
                $_SESSION[$_GET["key"]]["status"] = 9;
                $_SESSION[$_GET["key"]]["error"] = 7;
            } else {
                $sucess = $this->_triggerEventHandlers($fileInputName) ? move_uploaded_file($_FILES[$fileInputName]["tmp_name"], Config::$fileUploadPath . $_FILES[$fileInputName]["name"]) : false;
                $_SESSION[$_GET["key"]]["error"] = -1;
                if(!$sucess){
                    $_SESSION[$_GET["key"]]["serverMessage"] = "Error saving file or was rejected.";
                    $_SESSION[$_GET["key"]]["status"] = 7;
                    $_SESSION[$_GET["key"]]["error"] = 10;
                }
            }
        } else {
            switch ($_FILES[$fileInputName]["error"]) {
                case 1:
                case 2:
                $_SESSION[$_GET["key"]]["serverMessage"] = "File over the maximum limit!";
                $_SESSION[$_GET["key"]]["status"] = 5;
                $_SESSION[$_GET["key"]]["error"] = 2;  
                    break;
                case 3:
                //partial upload when client just navigates away from an active upload. Cleanup session
                unset($_SESSION[$_GET["key"]]);
                    break;
                case 8:
                $_SESSION[$_GET["key"]]["serverMessage"] = "The upload was canceled!";
                $_SESSION[$_GET["key"]]["status"] = 4;
                $_SESSION[$_GET["key"]]["error"] = -1;
                    break;
                default:
                $_SESSION[$_GET["key"]]["serverMessage"] = "General error. " . $_FILES[$fileInputName]["error"];
                $_SESSION[$_GET["key"]]["status"] = 7;
                $_SESSION[$_GET["key"]]["error"] = 10;
                    break;
            }
        }
    }
    
    /**
     * Register handlers to be called when a file is about to be saved.
     * @param array $callback The function names to be called
     */
    function fileUploaded($callback){
        $this->_callbacks[] = $callback;
    }
    
    /**
     * Trigger registered event handlers
     * @return bool Flag if user handle accepted the file
     */
    private function _triggerEventHandlers($fileInputKey){
        $flag = true;
        foreach ($this->_callbacks as $functionName) {
            if(!call_user_func($functionName, $_GET["key"], $fileInputKey)){
                $flag = false;
            }
        }
        return $flag;
    }
}
?>
