<?php
/**
 * Upload Status Handler for the Ignite UI File Upload
 * 
 * 	PHP version 5.4
 * 
 * 	@package        Ignite UI PHP Wrappers
 * 	@version        1.0.2012.2056
 *
 */

namespace ig\upload;
/**
 * Module to handle status, size and cancel requests made by the Ignite UI Uploader
 *
 */
class igUploadSatusHandler {
    /**
     * Function to handle incoming status, size and cancel requests.
     */
    function handleRequests(){
        session_start();
        if (!isset($_GET["command"])) {
            return;
        }
        if ($_GET["command"] == 'fileSize') {
            //get size
            if (isset($_GET["key"]) && isset($_SESSION[$_GET["key"]])) {
                echo '{"fileSize":' . $_SESSION[$_GET["key"]]["size"] . '}';
            } else {
                // just return some arbitrary size when pre-upload is skipped (recommended) 
                echo '{"fileSize": 0}';
            }
            return;
        }

        if ($_GET["command"] == 'status') {
            $result = new igUploadResponse(-1, 0, 0, "", 1);
            if (isset($_GET["key"]) && isset($_SESSION[$_GET["key"]])) {
                $key = $_SESSION[$_GET["key"]]["key"];
                if (isset($_SESSION[$key])) {
                    //get size
                    $_SESSION[$_GET["key"]]["size"] = $_SESSION[$key]["content_length"];
                    //check for errors
                    if (isset($_SESSION[$_GET["key"]]["error"])) {
                        $result->status = $_SESSION[$_GET["key"]]["error"];
                    } elseif ($_SESSION[$key]["content_length"] == $_SESSION[$key]["bytes_processed"] && $_SESSION[$key]["files"][0]["done"] == 1) {
                        $result->status = 2;
                    }
                    $result->size = $_SESSION[$key]["content_length"];
                    $result->bytesUploaded = $_SESSION[$key]["bytes_processed"];
                    echo $result;
                } else {
                    // file finished? (or errored out?)
                    $result->size = $result->bytesUploaded = $_SESSION[$_GET["key"]]["size"];
                    if (isset($_SESSION[$_GET["key"]]["error"]) && $_SESSION[$_GET["key"]]["error"] == -1) {
                        //saved
                        $result->status = 2;
                        echo $result;
                    } elseif (isset($_SESSION[$_GET["key"]]["error"])){
                        $result->status = $_SESSION[$_GET["key"]]["status"];
                        $result->error = $_SESSION[$_GET["key"]]["error"];
                        $result->serverMessage = $_SESSION[$_GET["key"]]["serverMessage"];
                        echo $result;
                    }
                    unset($_SESSION[$_GET["key"]]);
                }
            }
            else {
                $result->status = 3;
                $result->error = 5;
                $result->serverMessage = "File key not found!";
                echo $result;
            }
            return;
        }

        if ($_GET["command"] == 'cancel') {
            if (isset($_GET["key"]) && isset($_SESSION[$_GET["key"]])) {
                $key = $_SESSION[$_GET["key"]]["key"];
                $_SESSION[$key]["cancel_upload"] = TRUE;
                $_SESSION[$_GET["key"]]["serverMessage"] = "The upload was canceled!";
                $_SESSION[$_GET["key"]]["error"] = -1; //no error
                $_SESSION[$_GET["key"]]["status"] = 4; //canceled
            }
            return;
        }

        if ($_GET["command"] == 'clear') {
            if (isset($_GET["key"]) && isset($_SESSION[$_GET["key"]])) {
                unset($_SESSION[$_GET["key"]]);
            }
            return;
        }
    }
}

/**
 * A wrapper class for the responses the handler needs to generate for status requests.
 */
class igUploadResponse {

    /** @var int $error Error type -1 to 10. */
    public $error;

    /** @var int $size Total file size. */
    public $size;

    /** @var int $bytesUploaded Total bytes currently processed. */
    public $bytesUploaded;

    /** @var string $serverMessage Text message from the server. */
    public $serverMessage;

    /** @var int $status The status state from 0 to 9 */
    public $status;

    /**
     * Constructs an Ignite UI Upload server status response as per :
     * http://help.infragistics.com/NetAdvantage/jQuery/2012.2/CLR4.0?page=igUpload_Using_HTTP_Handler_and_Modules.html
     * 
     * @param int $error Error type -1 to 10.
     * @param int $size Total file size.
     * @param string $serverMessage Text message from the server.
     * @param int $status The status state from 0 to 9.
     */
    function __construct($error, $size, $bytesUploaded, $serverMessage, $status) {
        $this->error = $error;
        $this->size = $size;
        $this->bytesUploaded = $bytesUploaded;
        $this->serverMessage = $serverMessage;
        $this->status = $status;
    }

    function __toString() {
        return json_encode($this);
    }

}

?>